ModelServerCommandCondition class

Condition class used in ModelServerCommandBase.

ModelServerCommandBaseで用いる条件クラス。

Annotations

Constructors

ModelServerCommandCondition({required String key, ModelQueryFilterType? type, Object? value})
Condition class used in ModelServerCommandBase.
const
ModelServerCommandCondition.fromJson(DynamicMap json)
Convert from json map to ModelServerCommandCondition.
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
key → String
Key Terms.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ModelQueryFilterType?
Condition type.
final
value → Object?
Condition Value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → DynamicMap
Methods for Json serialization.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

kKeyKey → const String
Key key.
kTypeKey → const String
Type key.
kValueKey → const String
Value key.
typeString → const String
Object type key.