ModelUpdateNotification class

This class contains data for change notifications.

変更通知を行う際のデータを格納したクラスです。

Annotations

Constructors

ModelUpdateNotification({required String path, required String id, required ModelUpdateNotificationStatus status, required DynamicMap value, required bool listen, required ModelQuery query, Object? origin, int? oldIndex, int? newIndex})
This class contains data for change notifications.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
ID of the document being modified.
final
listen → bool
true` if the query is being monitored.
final
newIndex → int?
Index of the modified collection.
final
oldIndex → int?
Index of the collection before the change.
final
origin → Object?
The document/collection object you passed with ModelAdapterDocumentQuery when you passed it.
final
path → String
The path of the modified document.
final
query → ModelQuery
ModelQuery to be updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → ModelUpdateNotificationStatus
Change status when changes are made.
final
value → DynamicMap
Modified document value (DynamicMap).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited